pub(super) fn enrolment_lookup(
context: &SubmissionContext,
) -> Result<Askable, Unaskable>Expand description
What to ask the registry about the row’s enrolment, or why it cannot be asked about.
pub(super) fn enrolment_lookup(
context: &SubmissionContext,
) -> Result<Askable, Unaskable>What to ask the registry about the row’s enrolment, or why it cannot be asked about.